Group {
  DefineGroup[Domain_Disp] ;
  DomainTot = #{Domain_Disp};
}

Function {
}

/* Meca_u : Mechanics - Displacement ux, uy, uz formulations */

FunctionSpace {
  { Name H_u_Mec3D ; Type Vector ;
    BasisFunction {
        /* ux = ux  sx , for all nodes
                  n   n                */
    { Name sxn ; NameOfCoef uxn ; Function BF_NodeX ;
        Support DomainTot ; Entity NodesOf[ All ] ; }
      { Name syn ; NameOfCoef uyn ; Function BF_NodeY ;
        Support DomainTot ; Entity NodesOf[ All ] ; }
      { Name szn ; NameOfCoef uzn ; Function BF_NodeZ ;
        Support DomainTot ; Entity NodesOf[ All ] ; }
    }
    Constraint {
      { NameOfCoef uxn ;
        EntityType NodesOf ; NameOfConstraint DeplacementX ; }
      { NameOfCoef uyn ;
        EntityType NodesOf ; NameOfConstraint DeplacementY ; }
      { NameOfCoef uzn ;
        EntityType NodesOf ; NameOfConstraint DeplacementZ ; }
    }
  }
}

Formulation {
  { Name Elasticite3D_u_statique ; Type FemEquation ;
    Quantity {
      { Name u ; Type Local ; NameOfSpace H_u_Mec3D ; }
      { Name v ; Type Local ; NameOfSpace Hgrad_v_EleKin ; }
    }

    Equation {
                                                              //      11 
       Galerkin { [ C_11[] * Dof{D1 u} , {D1 u} ] ;          // --> K         
                      In Domain_Disp ;                      //       u u
                     Jacobian Vol ; Integration GradGrad ; } 
                                                              //     22
       Galerkin { [ C_22[] * Dof{D2 u} , {D2 u} ] ;          // --> K   
                   In Domain_Disp ;                         //       u u  
                   Jacobian Vol ; Integration GradGrad ; } 
                                                              //     12
       Galerkin { [ C_12[] * Dof{D2 u} , {D1 u} ] ;          // --> K         
                      In Domain_Disp ;                      //       u u
                     Jacobian Vol ; Integration GradGrad ; } 
                                                              //     21
       Galerkin { [ C_21[] * Dof{D1 u} , {D2 u} ] ;          // --> K   
                   In Domain_Disp ;                         //       u u  
                   Jacobian Vol ; Integration GradGrad ; } 

       //Galerkin { [ -F[] , {u} ] ;      
       Galerkin { [ - (-sigma[] * {d v} /\ bext[]) , {u} ] ;      
                   In Domain_Force;
                   Jacobian Vol; Integration GradGrad; }  
    }
  }
  { Name Elasticite3D_u_transitoire ; Type FemEquation ;
    Quantity {
      { Name u ; Type Local ; NameOfSpace H_u_Mec3D ; }
      { Name v ; Type Local ; NameOfSpace Hgrad_v_EleKin ; }
    }
    Equation {
                                                              //      11 
       Galerkin { [ C_11[] * Dof{D1 u} , {D1 u} ] ;          // --> K         
                      In Domain_Disp ;                      //       u u
                     Jacobian Vol ; Integration GradGrad ; } 
                                                              //     22
       Galerkin { [ C_22[] * Dof{D2 u} , {D2 u} ] ;          // --> K   
                   In Domain_Disp ;                         //       u u  
                   Jacobian Vol ; Integration GradGrad ; } 
                                                              //     12
       Galerkin { [ C_12[] * Dof{D2 u} , {D1 u} ] ;          // --> K         
                      In Domain_Disp ;                      //       u u
                     Jacobian Vol ; Integration GradGrad ; } 
                                                              //     21
       Galerkin { [ C_21[] * Dof{D1 u} , {D2 u} ] ;          // --> K   
                   In Domain_Disp ;                         //       u u  
                   Jacobian Vol ; Integration GradGrad ; } 
       Galerkin { DtDt [ rho[] * Dof{u} , {u} ];              //
                   In Domain_Disp ;                          // --> rho*omega^2*u u
                   Jacobian Vol ; Integration GradGrad ; }  // 
       /* Ajouter terme(s) de damping:
       Galerkin { Dt [ XXX Dof{u} , {u} ];              //
                   In Domain_Disp ;                         // --> 
                   Jacobian Vol ; Integration GradGrad ; }  // 
       */
    }
  }
  { Name Elasticite3D_u_modal ; Type FemEquation ;
    Quantity {
      { Name u ; Type Local ; NameOfSpace H_u_Mec3D ; }
      { Name v ; Type Local ; NameOfSpace Hgrad_v_EleKin ; }
    }
    Equation {
                                                              //      11 
       Galerkin { [ C_11[] * Dof{D1 u} , {D1 u} ] ;          // --> K         
                      In Domain_Disp ;                      //       u u
                     Jacobian Vol ; Integration GradGrad ; } 
                                                              //     22
       Galerkin { [ C_22[] * Dof{D2 u} , {D2 u} ] ;          // --> K   
                   In Domain_Disp ;                         //       u u  
                   Jacobian Vol ; Integration GradGrad ; } 
                                                              //     12
       Galerkin { [ C_12[] * Dof{D2 u} , {D1 u} ] ;          // --> K         
                      In Domain_Disp ;                      //       u u
                     Jacobian Vol ; Integration GradGrad ; } 
                                                              //     21
       Galerkin { [ C_21[] * Dof{D1 u} , {D2 u} ] ;          // --> K   
                   In Domain_Disp ;                         //       u u  
                   Jacobian Vol ; Integration GradGrad ; } 

       Galerkin { DtDt [ rho[] * Dof{u} , {u} ];              //
                   In Domain_Disp ;                          // --> rho*omega^2*u u
                   Jacobian Vol ; Integration GradGrad ; }  // 
    }
  }
}

/*------------------------------------------------------------------------*/
/*------------------------------------------------------------------------*/

Resolution {
  { Name Elasticite3D_u_couple_statique ;
    System {
      { Name Sys_EleKin ; NameOfFormulation Electrokinetics_v ; }
      { Name Sys_Mec; NameOfFormulation Mec3D_u; }
    }
    Operation {
      Generate Sys_EleKin ; Solve Sys_EleKin ; SaveSolution Sys_EleKin ;
      Generate[Sys_Mec]; Solve[Sys_Mec]; SaveSolution[Sys_Mec] ;
    }
  }
  { Name Elasticite3D_u_modal ;
    System {
      { Name Sys_Mec; NameOfFormulation Mec3D_u; Type Complex; }
    }
    Operation {
      GenerateSeparate[Sys_Mec]; 
      EigenSolve[Sys_Mec, 5, 0, 0]; 
      SaveSolutions[Sys_Mec] ;
    }
  }
}

/*------------------------------------------------------------------------*/

PostProcessing {

  { Name Elasticite3D ; NameOfFormulation Elasticite3D_u_couple_statique ;  
    PostQuantity {
        { Name u  ; Value { Term { [ {u} ]     ; In Domain_Disp  ; } } }
        { Name ux  ; Value { Term { [CompX[{u}]]      ; In Domain_Disp  ; } } }
        { Name uy  ; Value { Term { [CompY[{u}]]      ; In Domain_Disp  ; } } }
        { Name uz  ; Value { Term { [CompZ[{u}]]      ; In Domain_Disp  ; } } }
        { Name epsI ; Value { Term { [ {D1 u} ]   ; In Domain_Disp ; } } }
        { Name epsII ; Value { Term { [ {D2 u} ]   ; In Domain_Disp ; } } }

        { Name epsx ; Value { Term { [Vector [CompX[{D1 u}],0,0 ] ]    ; In Domain_Disp ; } } }
        { Name epsy ; Value { Term { [Vector [0, CompY[{D1 u}],0 ] ]    ; In Domain_Disp ; } } }
        { Name epsz ; Value { Term { [Vector [0, 0, CompZ[{D1 u}] ] ]    ; In Domain_Disp ; } } }

        { Name epsxy ; Value { Term { [Vector [CompX[{D2 u}],0,0 ] ]    ; In Domain_Disp ; } } }
        { Name epsyz ; Value { Term { [Vector [0, CompY[{D2 u}],0 ] ]    ; In Domain_Disp ; } } }
        { Name epszx ; Value { Term { [Vector [0, 0, CompZ[{D2 u}] ] ]    ; In Domain_Disp ; } } }   

        { Name y ; Value { Term { [ Y[] ]    ; In Domain_Disp ; } } }

        { Name um ; Value { Term { [Norm[{u}]] ; In Domain_Disp  ; } } }
 
   } 
  }
}


