Include "magnetometre.dat";

DEGRE2 = 0; // set to 1 for 2nd order elastic computation

Group {
  // electrical
  DomainC_Ele = Region[ {Poutre, ConducteurGauche, ConducteurDroit} ] ;
  Dirichlet0 = Region[{PotentielGauche}];
  Dirichlet1 = Region[{PotentielDroit}];

  // mechanical
  Domain_Disp = Region[{DomainC_Ele}];
  Encastrement = Region[{EncastrementGauche, EncastrementDroit}];
  Domain_Force = Region[{Domain_Disp}];

  // thermal
  Domain_The = Region[{DomainC_Ele}];
  SurfaceConv_The = Region[{}];
}

Function {
  // electrical
  sigma[ Region[{Poutre}] ] = 37e6 ;
  sigma[ Region[{ConducteurGauche, ConducteurDroit}] ] = 37e6 ;
  bext[] = Vector[0, -1e-6, 0];

  // mechanical
  //F[] = Vector[0, 0, 10];
  E[Domain_Disp] = 70e9 ; nu = 0.3 ;

  //Cij = [ C11   C12
  //        C21   C22];
  //Cij = E/(1+nu)/(1-2nu)*
  //[ 1-nu        nu         nu         0                  0                  0
  //    nu      1-nu         nu         0                  0                  0
  //    nu        nu       1-nu         0                  0                  0
  //     0         0          0      (1-2nu)/2             0                  0
  //     0         0          0         0               (1-2nu)/2             0
  //     0         0          0         0                  0              (1-2nu)/2 ]

  ff[] = E[]/(1+nu)/(1-2*nu);
  c11 = 1-nu ;
  c12 = nu ;
  c44 = (1-2*nu)/2 ;
  C_11[Domain_Disp] = ff[] * TensorSym[ c11, c12, c12, c11, c12, c11 ];
  C_22[Domain_Disp] = ff[] * TensorSym[ c44, 0, 0, c44, 0, c44 ];
  C_12[Domain_Disp] = Tensor[0,0,0, 0,0,0, 0,0,0];
  C_21[Domain_Disp] = Tensor[0,0,0, 0,0,0, 0,0,0];

  rho[] = 2700; // vol. mas

  lambda[] = 237;
  rhoc[] = 2.e6; // vol. mass * heat capacity

  h[] = 1.4; // convection coef (unused)
  TemperatureConv[] = 20;

  Freq = 243740;
  coef_alpha =  0;//9.889460399076600e-11;
  //coef_beta = 68.413834898694205;
  //coef_beta = 101.1177515907109;
  coef_beta = 0;
}

Constraint {
  { Name ElectricScalarPotential ;
    Case {
      { Region Dirichlet0 ; Value 0. ; }
      { Region Dirichlet1 ; Value 0.00181 ; }
    }
  }
  { Name DeplacementX ;
    Case {
      { Region Encastrement ; Value 0. ; }
    }
  }
  { Name DeplacementY ;
    Case {
      { Region Encastrement ; Value 0. ; }
    }
  }
  { Name DeplacementZ ;
    Case {
      { Region Encastrement ; Value 0. ; }
    }
  }
  { Name Temperature ;
    Case {
      { Region Dirichlet0 ; Value 20. ; }
      { Region Dirichlet1 ; Value 20. ; }
    }
  }
}

Include "Jacobian_Lib.pro"
Include "Integration_Lib.pro"

Include "Electrocinetique.pro"
Include "Elasticite3D.pro"
Include "Thermique.pro"

PostOperation {
  { Name potentiel_electrique ; NameOfPostProcessing Electrocinetique;
    Operation {
      Print[ v, OnElementsOf DomainC_Ele, File "v.pos"] ;
    }
  }
  { Name champ_electrique ; NameOfPostProcessing Electrocinetique;
    Operation {
      Print[ e, OnElementsOf DomainC_Ele, File "e.pos"] ;
    }
  }
  { Name densite_de_courant ; NameOfPostProcessing Electrocinetique;
    Operation {
      Print[ j, OnElementsOf DomainC_Ele, File "j.pos"] ;
    }
  }
  { Name force ; NameOfPostProcessing Electrocinetique;
    Operation {
      Print[ f, OnElementsOf DomainC_Ele, File "f.pos"] ;
    }
  }
  { Name deplacement ; NameOfPostProcessing Elasticite3D;
    Operation {
      Print[ u, OnElementsOf Domain_Disp, File "u.pos"] ;
    }
  }
  { Name deplacement_z ; NameOfPostProcessing Elasticite3D;
    Operation {
      Print[ uz, OnElementsOf Domain_Disp, File "uz.pos"] ;
    }
  }
  { Name temperature ; NameOfPostProcessing Thermique;
    Operation {
      Print[ T, OnElementsOf Domain_The, File "T.pos"] ;
    }
  }
}
